@@ -17,7 +17,7 @@ from sklearn.linear_model import LogisticRegression
 
 #Gym environment
 
-class MyBoxDiEnv(gym.Env):
+class DiscreteEnv(gym.Env):
   def __init__(self, n = 200):
     self.size = n
     #get initial values for theta's
